==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Web_Links/language/lang-ukrainian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");


define("_PREVIOUS"," ");
define("_NEXT"," ");
define("_YOURNAME"," '");
define("_CATEGORY","");


define("_CATEGORIES","");
define("_LVOTES","");
define("_TOTALVOTES"," :");
define("_LINKTITLE"," ");
define("_HITS","ճ");

define("_THEREARE","");
define("_NOMATCHES","     ");
define("_SCOMMENTS","");
define("_DESCRIPTION","");
define("_SUBMITONCE","   .");
define("_POSTPENDING","     .");
define("_CHECKFORIT","ϳ      .");
define("_TOTALFORLAST","  ");
define("_BESTRATED"," ");
define("_CATNEWTODAY","    ");
define("_CATLAST3DAYS","       ");
define("_CATTHISWEEK","      ");
define("_DATE1","   .");
define("_DATE2","   .");
define("_PROMOTE02","");
define("_PROMOTE03","");
define("_PROMOTE04","");
define("_ONLYREGUSERSMODIFY","ҳ     .  , <a href=\"user.php\">    </a>.");
## define("_LETSDECIDE"," ,       .");
define("_RATENOTE4","    <a href=\"downloads.php?op=TopRated\">  </a>.");
define("_DATE","");
define("_TO","");
define("_ADDLINK","");
define("_NEW","");
define("_POPULAR","");
define("_TOPRATED","");
define("_RANDOM","");
define("_LINKSMAIN"," ");
define("_LINKCOMMENTS","");
define("_ADDITIONALDET","");
define("_EDITORREVIEW","");
define("_REPORTBROKEN","   ");
define("_LINKSMAINCAT"," ");
define("_AND","");
define("_INDB","   ");
define("_ADDALINK","  ");
define("_INSTRUCTIONS","");
define("_USERANDIP","         .");
define("_PAGETITLE"," ");
define("_PAGEURL","URL ");
define("_YOUREMAIL"," Email");
define("_LDESCRIPTION",": ( 255 )");
define("_ADDURL"," URL");
define("_LINKSNOTUSER1","        .");
define("_LINKSNOTUSER2","  ,        .");
define("_LINKSNOTUSER3","     .");
define("_LINKSNOTUSER4","        ?");
define("_LINKSNOTUSER5","ҳ      .");
define("_LINKSNOTUSER6","      .");
define("_LINKSNOTUSER7","      .");
define("_LINKSNOTUSER8","<a href=\"user.php\"></a>");
define("_LINKALREADYEXT",":  URL     !");
define("_LINKNOTITLE",":      !");
define("_LINKNOURL",":    URL  !");
define("_LINKNODESC",":      !");
define("_LINKRECEIVED","   . !");
define("_EMAILWHENADD","    Email,    .");
define("_NEWLINKS"," ");
define("_TOTALNEWLINKS","  ");
define("_LASTWEEK","  ");
define("_LAST30DAYS","  30 ");
define("_1WEEK","1 ");
define("_2WEEKS","2 ");
define("_30DAYS","30 ");
define("_SHOW","");
define("_DAYS","");
define("_ADDEDON","");


define("_RATING","");
define("_RATESITE","  ");
define("_DETAILS","");
define("_OF","");
define("_TRATEDLINKS","  ");
define("_TVOTESREQ","  ");
define("_SHOWTOP"," ");
define("_MOSTPOPULAR"," ");
define("_OFALL","");
define("_SORTLINKSBY","  ");
define("_SITESSORTED","");
define("_POPULARITY","");
define("_SELECTPAGE"," ");
define("_MAIN","");
define("_NEWTODAY"," ");
define("_NEWLAST3DAYS","    ");
define("_NEWTHISWEEK"," ");
define("_POPULARITY1","  ");
define("_POPULARITY2","  ");
define("_TITLEAZ","  ( A  )");
define("_TITLEZA","  (   A)");
define("_RATING1","  ");
define("_RATING2","  ");
define("_SEARCHRESULTS4"," ");
define("_USUBCATEGORIES","ϳ");
define("_LINKS","");
define("_TRY2SEARCH"," ");
define("_INOTHERSENGINES","   ");
define("_EDITORIAL","");
define("_LINKPROFILE"," ");
define("_EDITORIALBY"," ");
define("_NOEDITORIAL","     .");
define("_VISITTHISSITE","³  ");
define("_RATETHISSITE","  ");
define("_ISTHISYOURSITE","  ?");
define("_ALLOWTORATE","     !");
define("_LINKRATINGDET","  ");
define("_OVERALLRATING"," ");
define("_TOTALOF","");
define("_USER","");
define("_USERAVGRATING","  ");
define("_NUMRATINGS","# ");
define("_EDITTHISLINK","³ ");
define("_REGISTEREDUSERS","  ");
define("_NUMBEROFRATINGS"," ");
define("_NOREGUSERSVOTES","   ");
define("_BREAKDOWNBYVAL"," ");
define("_LTOTALVOTES","  ");
define("_LINKRATING"," ");
define("_HIGHRATING"," ");
define("_LOWRATING"," ");
define("_NUMOFCOMMENTS","ʳ ");
define("_WEIGHNOTE","* :        ");
define("_NOUNREGUSERSVOTES","   ");
define("_WEIGHOUTNOTE","* :           ");
define("_NOOUTSIDEVOTES","    ");
define("_OUTSIDEVOTERS","   ");
define("_UNREGISTEREDUSERS","  ");
define("_PROMOTEYOURSITE","  -");
define("_PROMOTE01",",             .      .       :");
define("_TEXTLINK","");
define("_HTMLCODE1","HTML-  :");
define("_THENUMBER"," ID");
define("_IDREFER","  ID    HTML .");
define("_BUTTONLINK","");
define("_RATEIT","  !");
define("_HTMLCODE2","   :");
define("_REMOTEFORM","  ");
define("_VOTE4THISSITE","   !");
define("_LINKVOTE","!");
define("_HTMLCODE3","             .   ,     HTML-.      -.:");
define("_PROMOTE05","  !");
define("_STAFF","");
define("_THANKSBROKEN","     ,        <br>       .");
define("_THANKSFORINFO","  .");
define("_LOOKTOREQUEST","     .");
define("_REQUESTLINKMOD","    ");
define("_LINKID","ID ");
define("_SENDREQUEST"," ");
define("_THANKSTOTAKETIME","   ,      ");
define("_RETURNTO","  ");
define("_RATENOTE1"," ,      .");
define("_RATENOTE2","  1  10. 1 -    10 - .");
define("_RATENOTE3"," ,  '  .");
define("_RATENOTE5","      .");
define("_YOUAREREGGED","     ");
define("_FEELFREE2ADD","³        .");
define("_YOUARENOTREGGED"," -       .");
define("_IFYOUWEREREG","        .");
define("_WEBLINKS","");
define("_TITLE","");
define("_MODIFY","");
define("_COMPLETEVOTE1","Your vote is appreciated.");
define("_COMPLETEVOTE2","You have already voted for this resource in the past $anonwaitdays day(s).");
define("_COMPLETEVOTE3","Vote for a resource only once.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE4","You cannot vote on a link you submitted.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE5","No rating selected - no vote tallied");
define("_COMPLETEVOTE6","Only one vote per IP address allowed every $outsidewaitdays day(s).");
define("_LINKSDATESTRING","%d.%m.%Y");


?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Web_Links/language/lang-ukrainian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");


define("_PREVIOUS"," ");
define("_NEXT"," ");
define("_YOURNAME"," '");
define("_CATEGORY","");


define("_CATEGORIES","");
define("_LVOTES","");
define("_TOTALVOTES"," :");
define("_LINKTITLE"," ");
define("_HITS","ճ");

define("_THEREARE","");
define("_NOMATCHES","     ");
define("_SCOMMENTS","");
define("_DESCRIPTION","");
define("_SUBMITONCE","   .");
define("_POSTPENDING","     .");
define("_CHECKFORIT","ϳ      .");
define("_TOTALFORLAST","  ");
define("_BESTRATED"," ");
define("_CATNEWTODAY","    ");
define("_CATLAST3DAYS","       ");
define("_CATTHISWEEK","      ");
define("_DATE1","   .");
define("_DATE2","   .");
define("_PROMOTE02","");
define("_PROMOTE03","");
define("_PROMOTE04","");
define("_ONLYREGUSERSMODIFY","ҳ     .  , <a href=\"user.php\">    </a>.");
## define("_LETSDECIDE"," ,       .");
define("_RATENOTE4","    <a href=\"downloads.php?op=TopRated\">  </a>.");
define("_DATE","");
define("_TO","");
define("_ADDLINK","");
define("_NEW","");
define("_POPULAR","");
define("_TOPRATED","");
define("_RANDOM","");
define("_LINKSMAIN"," ");
define("_LINKCOMMENTS","");
define("_ADDITIONALDET","");
define("_EDITORREVIEW","");
define("_REPORTBROKEN","   ");
define("_LINKSMAINCAT"," ");
define("_AND","");
define("_INDB","   ");
define("_ADDALINK","  ");
define("_INSTRUCTIONS","");
define("_USERANDIP","         .");
define("_PAGETITLE"," ");
define("_PAGEURL","URL ");
define("_YOUREMAIL"," Email");
define("_LDESCRIPTION",": ( 255 )");
define("_ADDURL"," URL");
define("_LINKSNOTUSER1","        .");
define("_LINKSNOTUSER2","  ,        .");
define("_LINKSNOTUSER3","     .");
define("_LINKSNOTUSER4","        ?");
define("_LINKSNOTUSER5","ҳ      .");
define("_LINKSNOTUSER6","      .");
define("_LINKSNOTUSER7","      .");
define("_LINKSNOTUSER8","<a href=\"user.php\"></a>");
define("_LINKALREADYEXT",":  URL     !");
define("_LINKNOTITLE",":      !");
define("_LINKNOURL",":    URL  !");
define("_LINKNODESC",":      !");
define("_LINKRECEIVED","   . !");
define("_EMAILWHENADD","    Email,    .");
define("_NEWLINKS"," ");
define("_TOTALNEWLINKS","  ");
define("_LASTWEEK","  ");
define("_LAST30DAYS","  30 ");
define("_1WEEK","1 ");
define("_2WEEKS","2 ");
define("_30DAYS","30 ");
define("_SHOW","");
define("_DAYS","");
define("_ADDEDON","");


define("_RATING","");
define("_RATESITE","  ");
define("_DETAILS","");
define("_OF","");
define("_TRATEDLINKS","  ");
define("_TVOTESREQ","  ");
define("_SHOWTOP"," ");
define("_MOSTPOPULAR"," ");
define("_OFALL","");
define("_SORTLINKSBY","  ");
define("_SITESSORTED","");
define("_POPULARITY","");
define("_SELECTPAGE"," ");
define("_MAIN","");
define("_NEWTODAY"," ");
define("_NEWLAST3DAYS","    ");
define("_NEWTHISWEEK"," ");
define("_POPULARITY1","  ");
define("_POPULARITY2","  ");
define("_TITLEAZ","  ( A  )");
define("_TITLEZA","  (   A)");
define("_RATING1","  ");
define("_RATING2","  ");
define("_SEARCHRESULTS4"," ");
define("_USUBCATEGORIES","ϳ");
define("_LINKS","");
define("_TRY2SEARCH"," ");
define("_INOTHERSENGINES","   ");
define("_EDITORIAL","");
define("_LINKPROFILE"," ");
define("_EDITORIALBY"," ");
define("_NOEDITORIAL","     .");
define("_VISITTHISSITE","³  ");
define("_RATETHISSITE","  ");
define("_ISTHISYOURSITE","  ?");
define("_ALLOWTORATE","     !");
define("_LINKRATINGDET","  ");
define("_OVERALLRATING"," ");
define("_TOTALOF","");
define("_USER","");
define("_USERAVGRATING","  ");
define("_NUMRATINGS","# ");
define("_EDITTHISLINK","³ ");
define("_REGISTEREDUSERS","  ");
define("_NUMBEROFRATINGS"," ");
define("_NOREGUSERSVOTES","   ");
define("_BREAKDOWNBYVAL"," ");
define("_LTOTALVOTES","  ");
define("_LINKRATING"," ");
define("_HIGHRATING"," ");
define("_LOWRATING"," ");
define("_NUMOFCOMMENTS","ʳ ");
define("_WEIGHNOTE","* :        ");
define("_NOUNREGUSERSVOTES","   ");
define("_WEIGHOUTNOTE","* :           ");
define("_NOOUTSIDEVOTES","    ");
define("_OUTSIDEVOTERS","   ");
define("_UNREGISTEREDUSERS","  ");
define("_PROMOTEYOURSITE","  -");
define("_PROMOTE01",",             .      .       :");
define("_TEXTLINK","");
define("_HTMLCODE1","HTML-  :");
define("_THENUMBER"," ID");
define("_IDREFER","  ID    HTML .");
define("_BUTTONLINK","");
define("_RATEIT","  !");
define("_HTMLCODE2","   :");
define("_REMOTEFORM","  ");
define("_VOTE4THISSITE","   !");
define("_LINKVOTE","!");
define("_HTMLCODE3","             .   ,     HTML-.      -.:");
define("_PROMOTE05","  !");
define("_STAFF","");
define("_THANKSBROKEN","     ,        <br>       .");
define("_THANKSFORINFO","  .");
define("_LOOKTOREQUEST","     .");
define("_REQUESTLINKMOD","    ");
define("_LINKID","ID ");
define("_SENDREQUEST"," ");
define("_THANKSTOTAKETIME","   ,      ");
define("_RETURNTO","  ");
define("_RATENOTE1"," ,      .");
define("_RATENOTE2","  1  10. 1 -    10 - .");
define("_RATENOTE3"," ,  '  .");
define("_RATENOTE5","      .");
define("_YOUAREREGGED","     ");
define("_FEELFREE2ADD","³        .");
define("_YOUARENOTREGGED"," -       .");
define("_IFYOUWEREREG","        .");
define("_WEBLINKS","");
define("_TITLE","");
define("_MODIFY","");
define("_COMPLETEVOTE1","Your vote is appreciated.");
define("_COMPLETEVOTE2","You have already voted for this resource in the past $anonwaitdays day(s).");
define("_COMPLETEVOTE3","Vote for a resource only once.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE4","You cannot vote on a link you submitted.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE5","No rating selected - no vote tallied");
define("_COMPLETEVOTE6","Only one vote per IP address allowed every $outsidewaitdays day(s).");
define("_LINKSDATESTRING","%d.%m.%Y");


?>
